% open GUI editor with guide command


global guiHandler
guiHandler = mixerDemoGui

tic;

bitPattern = [1 0 1 0 1 0 1 0 1 1 1 1 0 0 0];
bitPattern = [1 0  1 0  0 1  1 0  1 1  1 1  0 0  0 0  1 1  1 1  0 0];
bitPatternLen = length(bitPattern);

global fjOrig    % frequency of the carrier
global fjMix     % frequency of the mixer
global mixerSignalInitialPhase  % the initial phase of the mixer

global isRotActive     % the simulation is running
global plotConjPhasor  % indicates whether the conjugate vector is plot
global plotRotatingCoordSys % indicates whether the rotating coordinate system is plot or not
    
global newBitEnabled   % indicates whether a new bit can be given: it is a new symbol period after a bit has already been given 
global NEW_BIT_BUFFER_SIZE % size of the buffer that stores the bits given manually
global newBits  % values of the new bits

global phaseCarrier   % phase of the carrier
global phaseMix       % phase of the mixer

global symbolPeriod   % the period of one symbol

global filtCoef

global bitOrderNumberAuto    % stores the order number of the actual bit that is used in the case of auto mode   (the transmitted bits are given as a predefined sequence)
global bitOrderNumberManual  % stores the order number of the actual bit that is used in the case of manual mode (the transmitted bits are given manually)

global bitBorder   % indicates that a new bit is used


% ----
% modulation types
% radio buttons
global typeOfModulation  % the type of modulation

%the following constants define the modulation types
global MODULATION_NO_MODULATION
global MODULATION_BPSK
global MODULATION_QPSK
global MODULATION_OQPSK
global MODULATION_MSK
global MODULATION_FSK

MODULATION_NO_MODULATION = 0;
MODULATION_BPSK          = 1;
MODULATION_QPSK          = 2;
MODULATION_OQPSK         = 3;
MODULATION_MSK           = 4;
MODULATION_FSK           = 5;


phaseCarrier = 0;   % instantaneous phase of the carrier
phaseMix = 0;       % instantaneous phase of the mixer

NEW_BIT_BUFFER_SIZE = 10;
newBits = zeros(1,NEW_BIT_BUFFER_SIZE);
newBitEnabled = 0; % it is enabled to give a new bit

% is the simulation running
isRotActive = 1;

% the 'sampling frequency'
fsMixSim = 8;
TsMixSim = 1/fsMixSim;


fjOrig  = 0.5;  % the carrier frequency
fjMix   = 0;    % the mixer frequency
fjFSK_D = 0.25; % the freq. deviation of FSK modulation
mixerSignalInitialPhase = 0; 
phaseModFSK = 0; % phase of FSK modulator
phaseModMSK = 0; % phase of MSK modulator
fModulation = 0.8;  % if a modulation signal is given

symbolPeriod = 2;

symbolPeriod_BPSK  = symbolPeriod;
symbolPeriod_QPSK  = symbolPeriod;
symbolPeriod_OQPSK = symbolPeriod;
symbolPeriod_MSK   = symbolPeriod;
symbolPeriod_FSK   = symbolPeriod;

% saves the time function of the modulated signal and baseband signals
TsaveInterv = 10; % the lengt of the time interval where variables are saved
NSaveFunctions = TsaveInterv * fsMixSim;
posInCircSaveBuffsTmp = 0; posInCircSaveBuffs = mod(posInCircSaveBuffsTmp,NSaveFunctions)+1;
timeAxisForSavedFuncs = [0:NSaveFunctions-1]*TsMixSim;
saveModulatedSignal      = zeros(1,NSaveFunctions);
saveModulatedBasebSignal_I = zeros(1,NSaveFunctions);
saveModulatedBasebSignal_Q = zeros(1,NSaveFunctions);
saveCarrierSignal        = zeros(1,NSaveFunctions);
saveModulatorSignal_I = zeros(1,NSaveFunctions);
saveModulatorSignal_Q = zeros(1,NSaveFunctions);

% number of simulation periods
rotN = 0;  

%filter forgetting coefficient
decrFactFilt  = 1e-2;
filtDecInStep = 3;
filtCoef = exp(log(decrFactFilt)/filtDecInStep); %the unexcited vector decreases to decrFactFilt in filtDecInStep steps
mixedCarrierFilt     = 0; 
mixedCarrierConjFilt = 0;

% select the axis
axesHandlerPlot = gethandlerToComp(guiHandler,'axes1');
axesHandlerTimeFunctionModCarr = gethandlerToComp(guiHandler,'Time_fun');

% points of a unit circle
circRad = [0:1e-1:2*pi+0.1];circPoints = exp(1j*circRad); %point of circles


% set the textboxes
set(gethandlerToComp(guiHandler,'f_sig_text')          ,  'String' , num2str(fjOrig))
set(gethandlerToComp(guiHandler,'f_mix_text')          ,  'String' , num2str(fjMix))
set(gethandlerToComp(guiHandler,'phase_mix_val')       ,  'String' , num2str(mixerSignalInitialPhase))
set(gethandlerToComp(guiHandler,'Symbol_period_val')   ,  'String' , num2str(symbolPeriod))
set(gethandlerToComp(guiHandler,'Filt_coef')           ,  'String' , num2str(filtCoef))

% get the properties and handlers of components
plotConjPhasor           = get(gethandlerToComp(guiHandler,'Plot_conj'),'Value')>0;
handlPlotConjPhasor      = gethandlerToComp(guiHandler,'Plot_conj');
handlPlotFilteredPhasor  = gethandlerToComp(guiHandler,'Filter_on');
handlPlotRotatingCoordSys= gethandlerToComp(guiHandler,'Plot_rot_coord');
handlI_displ_text        = gethandlerToComp(guiHandler,'I_displ_text'); 
handlQ_displ_text        = gethandlerToComp(guiHandler,'Q_displ_text'); 
handlManual_bit_set      = gethandlerToComp(guiHandler,'Manual_bit_set');
handlCoherent_demod      = gethandlerToComp(guiHandler,'coherent_demod');

timeFull = 0;
oldTimeLastIter = toc;

bitOrderNumberAuto   = 0;
bitOrderNumberManual = 0;

bitOrderNumberAutoOld   = 0;
bitOrderNumberManualOld = 0;

bitOrderNumber_gen_old = -1;  % the order number of bit that is transmitted (i.e. how many bits have already been transmitted)
bitOrderNumber_gen     = -1;     

bitAlreadyUsed   = 0;  % the real number of bits that are used and generated

newBitIsRequired = 0; % a new bit is required

newBitOld = 0;  % the previeous transmitted bit
newBit    = 0;  % the actual transmitted bit

I_bit_trans = 0;
Q_bit_trans = 0;

%%
% ****************************************
% *                                      *
% *   S T A R T    S I M U L A T I O N   *
% *                                      *
% ****************************************

%for rotNFor = 1:Nsim
%while ((isRotActive==1) & (toc<10)  )
while ((isRotActive==1)  )
   timeLastPlot = toc;

  typeOfModulation = getModulationType(guiHandler);

        switch typeOfModulation
            case MODULATION_NO_MODULATION, 
                %disp(['No mod'])% 
            case MODULATION_BPSK,
                %disp(['BPSK'])% 
            case MODULATION_QPSK,
                %disp(['QPSK'])% 
            case MODULATION_OQPSK,
                %disp(['OQPSK'])% 
            case MODULATION_MSK,
                %disp(['MSK'])% 
            case MODULATION_FSK,
                %disp(['FSK'])% 
            otherwise, 
                %disp(['Error'])% 
        end   
    %disp(['Proc: ' num2str(toc-timeLastPlot)]) %check the process time
   
   % start a new iteration

    rotN = rotN + 1;         % the number of iterations
    trot = rotN * TsMixSim;
    
    % the calculation the real elapsed time until the previous signal
    % processing point
    dTreal = -(oldTimeLastIter-toc);
    oldTimeLastIter = toc;
    %dTreal = TsMixSim;    % if the time is not measured
    timeFull = timeFull + dTreal;

    % set the symbol periods
    symbolPeriod_BPSK  = symbolPeriod;
    symbolPeriod_QPSK  = 2 * symbolPeriod;
    symbolPeriod_OQPSK = symbolPeriod;
    symbolPeriod_MSK   = symbolPeriod;
    symbolPeriod_FSK   = symbolPeriod;
    symbolPeriod_use = symbolPeriod;
    
        switch typeOfModulation
            case MODULATION_NO_MODULATION, 
                symbolPeriod_use = symbolPeriod; %disp(['No mod'])% 
            case MODULATION_BPSK,
                symbolPeriod_use = symbolPeriod_BPSK; %disp(['BPSK'])% 
            case MODULATION_QPSK,
                symbolPeriod_use = symbolPeriod_QPSK / 2; %disp(['QPSK'])% 
            case MODULATION_OQPSK,
                symbolPeriod_use = symbolPeriod_OQPSK; %disp(['OQPSK'])% 
            case MODULATION_MSK,
                symbolPeriod_use = symbolPeriod_MSK; %disp(['MSK'])% 
            case MODULATION_FSK,
                symbolPeriod_use = symbolPeriod_FSK; %disp(['FSK'])% 
            otherwise, 
                symbolPeriod_use = symbolPeriod; %disp(['Error'])% 
        end       
        
% ..............................................
% generates the new bit to transmit        
    bitOrderNumber_gen_old = bitOrderNumber_gen;
    bitOrderNumber_gen     = floor(timeFull/symbolPeriod_use);     
    
    newBitIsRequired = (bitOrderNumber_gen_old ~= bitOrderNumber_gen);
    
    if (get(handlManual_bit_set,'Value')>0)
        bitAlreadyUsed = bitAlreadyUsed + 1;
    else  % automatic bit generation
        if (newBitIsRequired==1)
            newBitOld = newBit;
            newBit    = bitPattern(mod(bitOrderNumber_gen,bitPatternLen)+1);
            %disp([num2str(bitOrderNumber_gen) '. bit is transmitted: ' num2str(newBit) ' (old: ' num2str(newBitOld) ')'])
            bitAlreadyUsed = bitAlreadyUsed + 1;
        else
        end
    end
    %disp(['Proc: ' num2str(toc-timeLastPlot)]) %check the process time

%*************************************************
%*    generate the baseband modulating signals   *
%*************************************************

    %modulatorSignal =1+0.3*sin(2*pi*fModulation*trot);
    phNum=2;
    timePhCh = symbolPeriod; 
    phaseMod = round( mod(timeFull, phNum*timePhCh)/timePhCh ) * 2*pi/phNum; 
    phaseMod = newBit * pi;
    modulatorSignal = exp(1j*phaseMod);

 
    switch typeOfModulation
        case MODULATION_NO_MODULATION, 
            modulatorSignal = 1;
            set(handlI_displ_text,'String',' ')
            set(handlQ_displ_text,'String',' ')
            %disp(['No mod'])% 
        case MODULATION_BPSK,
            phaseMod = (2*newBit-1) * pi/2;
            modulatorSignal = exp(1j*phaseMod);
            set(handlQ_displ_text,'String',['Q : ' num2str(newBit)])
            set(handlI_displ_text,'String',' ')
            %disp(['BPSK'])% 
        case MODULATION_QPSK,
            if (newBitIsRequired==1)
                if (mod(bitAlreadyUsed,2)==0)
                    I_bit_trans = newBit;
                    Q_bit_trans = newBitOld;
                end
            end
            set(handlI_displ_text,'String',['I : ' num2str(I_bit_trans)])
            set(handlQ_displ_text,'String',['Q: ' num2str(Q_bit_trans)])
            phaseQPSK00 = 225;
            phaseQPSK10 = 315;
            phaseQPSK01 = 135;
            phaseQPSK11 = 45;
            if ((I_bit_trans==0) & (Q_bit_trans==0))
                phaseMod = phaseQPSK00*pi/180; 
            elseif ((I_bit_trans==1) & (Q_bit_trans==0))
                phaseMod = phaseQPSK10*pi/180;
            elseif ((I_bit_trans==0) & (Q_bit_trans==1))
                phaseMod = phaseQPSK01*pi/180;
            elseif ((I_bit_trans==1) & (Q_bit_trans==1))
                phaseMod = phaseQPSK11*pi/180;
            else
                phaseMod = 0*pi/180;
            end
            modulatorSignal = exp(1j*phaseMod);
            %disp(['QPSK'])% 
        case MODULATION_OQPSK,
            if (newBitIsRequired==1)
                if (mod(bitAlreadyUsed,2)==0)
                    I_bit_trans = newBit;
                    set(handlI_displ_text,'String',['* I : ' num2str(I_bit_trans)])
                    set(handlQ_displ_text,'String',['>Q: ' num2str(Q_bit_trans)])
                else
                    Q_bit_trans = newBit;
                    set(handlI_displ_text,'String',['>I : ' num2str(I_bit_trans)])
                    set(handlQ_displ_text,'String',['*Q: ' num2str(Q_bit_trans)])
                end
            end % if (newBitIsRequired==1)
            phaseOQPSK00 = 225;
            phaseOQPSK10 = 315;
            phaseOQPSK01 = 135;
            phaseOQPSK11 = 45;
            if ((I_bit_trans==0) & (Q_bit_trans==0))
                phaseMod = phaseOQPSK00*pi/180;
            elseif ((I_bit_trans==1) & (Q_bit_trans==0))
                phaseMod = phaseOQPSK10*pi/180;
            elseif ((I_bit_trans==0) & (Q_bit_trans==1))
                phaseMod = phaseOQPSK01*pi/180;
            elseif ((I_bit_trans==1) & (Q_bit_trans==1))
                phaseMod = phaseOQPSK11*pi/180;
            else
                phaseMod = 0*pi/180;
            end
            modulatorSignal = exp(1j*phaseMod);
            %disp(['OQPSK'])% 
        case MODULATION_MSK,
            phaseModMSK = 2*pi/(4*symbolPeriod_MSK) * timeFull; %phase of modulator signal
            if (newBitIsRequired==1)
                %if (mod(bitAlreadyUsed,2)==0)
                %phaseForDecWhichBitMSK = mod(timeFull,4*symbolPeriod_MSK)
                phaseForDecWhichBitMSK = mod(timeFull,2*symbolPeriod_MSK)
                %if ((phaseForDecWhichBitMSK>0.75*2*symbolPeriod_MSK) & (symbolPeriod_MSK<1.45*2*symbolPeriod_MSK))
                if (abs(sin(phaseModMSK))<abs(cos(phaseModMSK)))
                    Q_bit_trans = newBit;
                    %sin(phaseModMSK)
                    set(handlI_displ_text,'String',['>I : ' num2str(I_bit_trans)])
                    set(handlQ_displ_text,'String',['*Q: ' num2str(Q_bit_trans)])
                else
                    I_bit_trans = newBit;
                    set(handlI_displ_text,'String',[' *I : ' num2str(I_bit_trans)])
                    set(handlQ_displ_text,'String',['>Q: ' num2str(Q_bit_trans)])
                end
            end % if (newBitIsRequired==1)
            if ((I_bit_trans==0) & (Q_bit_trans==0))
                modulatorSignal = -abs(cos(phaseModMSK)) - 1j*abs(sin(phaseModMSK));
            elseif ((I_bit_trans==1) & (Q_bit_trans==0))
                modulatorSignal =  abs(cos(phaseModMSK)) - 1j*abs(sin(phaseModMSK));
            elseif ((I_bit_trans==0) & (Q_bit_trans==1))
                modulatorSignal = -abs(cos(phaseModMSK)) + 1j*abs(sin(phaseModMSK));
            elseif ((I_bit_trans==1) & (Q_bit_trans==1))
                modulatorSignal =  abs(cos(phaseModMSK)) + 1j*abs(sin(phaseModMSK));
            else
                modulatorSignal = 1;
            end            
            %disp(['MSK'])% 
        case MODULATION_FSK,
            phaseModFSK = phaseModFSK + newBit * 2*pi*fjFSK_D * dTreal;
            modulatorSignal = exp(1j*phaseModFSK);
            set(handlI_displ_text,'String',['I : ' num2str(newBit)])
            set(handlQ_displ_text,'String',' ')
            %disp(['FSK'])% 
        otherwise, 
            %disp(['Error'])% 
    end   
        I_signal = real(modulatorSignal);
        Q_signal = imag(modulatorSignal);

    %disp(['Proc: ' num2str(toc-timeLastPlot)]) %check the process time
    
%*************************************************
%*  calculation of the RF and baseband signals   *
%*************************************************
    coherentDemod = get(handlCoherent_demod,'Value')>0;
    phaseCarrier     =  phaseCarrier + 2*pi*fjOrig*dTreal;
    phaseConjCarrier = -phaseCarrier;
    phaseMix     = phaseMix     + 2*pi*fjMix *dTreal;
    if (coherentDemod>0)
        phaseMix = phaseCarrier;
    end
    carrier      = exp(1j*phaseCarrier);
    carrierConj  = exp(1j*phaseConjCarrier);
    modCarrier   = carrier * modulatorSignal;
    modCarrierConj = conj(modCarrier);
    mixVect      = exp(-1j*(phaseMix + mixerSignalInitialPhase*pi/180));
    mixVectSign  = exp(-1j*(phaseMix + mixerSignalInitialPhase*pi/180 + [0:3]*pi/2));
    
    mixedCarrier     = modCarrier     * mixVect;
    mixedCarrierConj = modCarrierConj * mixVect;
    mixedCarrierSum  = mixedCarrierConj + mixedCarrier;
    
    %filter
    mixedCarrierFilt     = (1-filtCoef) * mixedCarrierFilt     + filtCoef * mixedCarrier;
    mixedCarrierConjFilt = (1-filtCoef) * mixedCarrierConjFilt + filtCoef * mixedCarrierConj;

% acquires settings    
    plotConjPhasor      = get(handlPlotConjPhasor      ,'Value')>0;
    plotFilteredPhasor  = get(handlPlotFilteredPhasor  ,'Value')>0;
    plotRotatingCoordSys= get(handlPlotRotatingCoordSys,'Value')>0;
    

    %disp(['Proc: ' num2str(toc-timeLastPlot)]) %check the process time
    
% **********************************************
% *      P L O T   O F   F I G U R E S         *
% **********************************************

     % ..........................................
     % :  C O N S T E L L A T I O N  D I A G R  :
     % :........................................:
     
    %figOld = gcf;
    %fig = figure(101100621);
    %clf
    %plot([0 real(carrier)],[0 imag(carrier)])
    axes(axesHandlerPlot) % switch to the plot axis
    %disp(['Proc -cd: ' num2str(toc-timeLastPlot)]) %check the process time
    %cla(axesHandlerPlot)  % clears 
    %disp(['Proc -cd: ' num2str(toc-timeLastPlot)]) %check the process time
    if (plotFilteredPhasor==0)
        plotVect = mixedCarrier;
    else 
        plotVect = mixedCarrierFilt;
    end
    %disp(['Proc -cd: ' num2str(toc-timeLastPlot)]) %check the process time

    plot(axesHandlerPlot,[0 real(plotVect)],[0 imag(plotVect)],'r','LineWidth',3) %plot the complex phasor
    set(axesHandlerPlot,'NextPlot','add'); %from now on, every plot is added
    %disp(['Proc -cd: ' num2str(toc-timeLastPlot)]) %check the process time

    if (plotConjPhasor)
        if (plotFilteredPhasor==0)
            plotConjVect = mixedCarrierConj;
        else 
            plotConjVect = mixedCarrierConjFilt;
        end        
        plot(axesHandlerPlot,[0 real(plotConjVect)],[0 imag(plotConjVect)],'Color',[255 140 140]/256,'LineWidth',3) %plot the complex phasor
    end
    %hold on
    plot(axesHandlerPlot,circPoints,'Color','b','LineWidth',2)
    % axis
    plot(axesHandlerPlot,[-1 1]*1.5,[0 0],'Color','k','LineWidth',1) %plot the x axis
    plot(axesHandlerPlot,[0 0],[-1 1]*1.5,'Color','k','LineWidth',1) %plot the y axis
    %hold off
    if (plotRotatingCoordSys==1)
        for circAxpl = 1:4
            scretchC = 1.1;
            %plot(axesHandlerPlot,real(mixVectSign(circAxpl))*[1 scretchC],imag(mixVectSign(circAxpl))*[1 scretchC],'Color','b','LineWidth',2)
            plot(axesHandlerPlot,real(mixVectSign(circAxpl))*[-1 1]*scretchC,imag(mixVectSign(circAxpl))*[-1 1]*scretchC,'Color','b','LineWidth',1)
        end        
        plot(axesHandlerPlot,[0 real(mixVect)],[0 imag(mixVect)],'b','LineWidth',2)
    end %if (plotRotatingCoordSys==1)        
    %disp(['Proc -cd: ' num2str(toc-timeLastPlot)]) %check the process time
    
    % signal the new bit border    
    if (newBitIsRequired==1)
        plot(axesHandlerPlot,[2 2],[2 2],'Color','r','Marker','o','LineWidth',6)
    else
        plot(axesHandlerPlot,[2 2],[2 2],'Color','b','Marker','o','LineWidth',6)
    end
    %disp(['Proc -cd: ' num2str(toc-timeLastPlot)]) %check the process time
    
    % set axes
    set(axesHandlerPlot,'NextPlot','replace');    
    axis(axesHandlerPlot,[-1 1 -1 1]*2)
    axis square    
    
    %disp(['Proc: ' num2str(toc-timeLastPlot)]) %check the process time
     % ..............................................
     % :  T I M E  F U N.  O F  MOD/BASB   S I G N  :
     % :............................................:
    % save and plot time function
    posInCircSaveBuffsTmp = posInCircSaveBuffsTmp + 1;
    posInCircSaveBuffs = mod(posInCircSaveBuffsTmp,NSaveFunctions)+1;
    saveModulatedSignal(posInCircSaveBuffs) = real(modCarrier);
    saveCarrierSignal(posInCircSaveBuffs) = real(carrier);
    saveModulatedBasebSignal_I(posInCircSaveBuffs) = real(mixedCarrier);
    saveModulatedBasebSignal_Q(posInCircSaveBuffs) = imag(mixedCarrier);
    saveModulatorSignal_I(posInCircSaveBuffs) = I_signal;
    saveModulatorSignal_Q(posInCircSaveBuffs) = Q_signal;

    plotBasebandSignal = get(gethandlerToComp(guiHandler,'Plot_baseband'),'Value')>0;
    %disp(['Proc -tf: ' num2str(toc-timeLastPlot)]) %check the process time
    
    axes(axesHandlerTimeFunctionModCarr) % switch to the plot axis
    %disp(['Proc -tf: ' num2str(toc-timeLastPlot)]) %check the process time
    %cla(axesHandlerTimeFunctionModCarr)  % clears 
    %disp(['Proc -tf: ' num2str(toc-timeLastPlot)]) %check the process time

    if (plotBasebandSignal==1)
        plot(axesHandlerTimeFunctionModCarr,timeAxisForSavedFuncs,2+[saveModulatedBasebSignal_I(posInCircSaveBuffs+1:end) saveModulatedBasebSignal_I(1:posInCircSaveBuffs)],'b','LineWidth',2) %plot the complex phasor
        set(axesHandlerTimeFunctionModCarr,'NextPlot','add'); %from now on, every plot is added
        plot(axesHandlerTimeFunctionModCarr,timeAxisForSavedFuncs,-2+[saveModulatedBasebSignal_Q(posInCircSaveBuffs+1:end) saveModulatedBasebSignal_Q(1:posInCircSaveBuffs)],'b','LineWidth',2) %plot the complex phasor
        axis(axesHandlerTimeFunctionModCarr,[0 NSaveFunctions*TsMixSim [-1 1]*4])
        plot(axesHandlerTimeFunctionModCarr,[0, NSaveFunctions*TsMixSim],[0 0],'k','LineWidth',2) %plot the complex phasor
        plot(axesHandlerTimeFunctionModCarr,[0, NSaveFunctions*TsMixSim],[0 0],'k','LineWidth',2) %plot the complex phasor
        plot(axesHandlerTimeFunctionModCarr,[0, NSaveFunctions*TsMixSim],[1 1]*2,'k','LineWidth',1, 'LineStyle',':') %plot the complex phasor
        plot(axesHandlerTimeFunctionModCarr,[0, NSaveFunctions*TsMixSim],[1 1]*-2,'k','LineWidth',1, 'LineStyle',':') %plot the complex phasor
        %set(axesHandlerTimeFunctionModCarr,'YTickLabel',['1' '0' '-1']); %from now on, every plot is added
        set(axesHandlerTimeFunctionModCarr,'YTickLabel',['   -1';'Q   0';' -1/1';'I   0';'    1'])

%         if (get(gethandlerToComp(guiHandler,'Plot_carrier'),'Value')>0)
%             plot(axesHandlerTimeFunctionModCarr,timeAxisForSavedFuncs,[saveModulatorSignal_I(posInCircSaveBuffs+1:end) saveModulatorSignal_I(1:posInCircSaveBuffs)],'r','LineWidth',1) %plot the complex phasor
%         end
    else
        plot(axesHandlerTimeFunctionModCarr,timeAxisForSavedFuncs,[saveModulatedSignal(posInCircSaveBuffs+1:end) saveModulatedSignal(1:posInCircSaveBuffs)],'b','LineWidth',2) %plot the complex phasor
        set(axesHandlerTimeFunctionModCarr,'NextPlot','add'); %from now on, every plot is added
        if (get(gethandlerToComp(guiHandler,'Plot_carrier'),'Value')>0)
            plot(axesHandlerTimeFunctionModCarr,timeAxisForSavedFuncs,[saveCarrierSignal(posInCircSaveBuffs+1:end) saveCarrierSignal(1:posInCircSaveBuffs)],'r','LineWidth',1) %plot the complex phasor
        end
        axis(axesHandlerTimeFunctionModCarr,[0 NSaveFunctions*TsMixSim [-1 1]*2])
    end
    %disp(['Proc -tf: ' num2str(toc-timeLastPlot)]) %check the process time
%    set(axesHandlerTimeFunctionModCarr,'NextPlot','add'); %from now on, every plot is added
    %disp(['Proc -tf: ' num2str(toc-timeLastPlot)]) %check the process time

    set(axesHandlerTimeFunctionModCarr,'NextPlot','replace');    
    %disp(['Proc: ' num2str(toc-timeLastPlot)]) %check the process time

    
    %figure(figOld);
    %toc-timeLastPlot % : the processing time. It is ~0.1 or greater 
    sampleTimeIsLong = 1;
    while (toc-timeLastPlot)<TsMixSim
        sampleTimeIsLong = 0;
        %we are waiting, unfortunately wasting time
    end    
    if (sampleTimeIsLong == 1)
        %%disp(['Processing time is not enough: ' num2str((toc-timeLastPlot))])
    end
    %disp('=============================77')
end; % end; %while (1==1),  %while ((isRotActive==1)  )





